/*
 * Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

/*
 * Abstract:
 * 	Module for configuring Fast Recovery relevant MADs
 *
 * Author:
 * 	Or Nechemia, NVIDIA
 */

#ifndef OSM_FAST_RECOVERY_H
#define OSM_FAST_RECOVERY_H

#include <iba/ib_types.h>
#include <complib/cl_types_osd.h>
#include <complib/cl_dispatcher.h>
#include <opensm/osm_subnet.h>
#include <opensm/osm_log.h>

struct osm_sm;

void osm_fast_recovery_configure(osm_subn_t * p_subn);

/****f* OpenSM: FastRecovery/osm_fast_recovery_set_profiles_configured
 * NAME
 *	osm_fast_recovery_set_profiles_configured
 *
 * DESCRIPTION
 *	Mark ProfileConfig block of the feature as configured successfully, or as not
 *	configured yet, according to is_configured.
 *
 * SYNOPSIS
 */
void osm_fast_recovery_set_profiles_configured(osm_switch_t * p_sw,
					       uint8_t block,
					       boolean_t is_configured);
/*
* PARAMETERS
*	p_sw
*		Pointer to switch.
*
*	block
*		Block number
*
*	is_configured
*		Boolean indicates whether to mark ProfilesConfig block of this feature
*		as configured or as not configured for this switch.
*
* RETURN VALUE
*	None
*
* NOTES
*
* SEE ALSO
*	profiles_configured field of fast recovery switch data
*********/


#endif                         /* ifndef OSM_FAST_RECOVERY_H */
